public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
From: "Anthony G. Basile" <blueness@gentoo.org>
To: gentoo-commits@lists.gentoo.org
Subject: [gentoo-commits] proj/webapp-config:master commit in: WebappConfig/
Date: Sat,  6 Aug 2011 01:51:28 +0000 (UTC)	[thread overview]
Message-ID: <6f368b35014b67c23d0eea35ed6791718f950af3.blueness@gentoo> (raw)

commit:     6f368b35014b67c23d0eea35ed6791718f950af3
Author:     Peter Volkov <pva <AT> gentoo <DOT> org>
AuthorDate: Sat Aug  6 01:50:52 2011 +0000
Commit:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
CommitDate: Sat Aug  6 01:50:52 2011 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/webapp-config.git;a=commit;h=6f368b35

Fix overwrite of existing config_protected files

webapp-config records the md5sum of previously modified config
file and any subsequent update removes that file since md5sum of
file in database (.webapp-app-version) is the same as on the disc.

Reported-By: Philippe Chaintreuil
Signed-off-by: Anthony G. Basile <blueness <AT> gentoo.org>
X-Gentoo-Bug: 243260
X-Gentoo-Bug-URL: http://bugs.gentoo.org/show_bug.cgi?id=243260

---
 WebappConfig/content.py |    7 +++++--
 WebappConfig/worker.py  |    2 ++
 2 files changed, 7 insertions(+), 2 deletions(-)

diff --git a/WebappConfig/worker.py b/WebappConfig/worker.py
index e73bce3..a5ee172 100644
--- a/WebappConfig/worker.py
+++ b/WebappConfig/worker.py
@@ -386,6 +386,7 @@ class WebappAdd:
                            dirtype,
                            self.__destd,
                            directory,
+                           directory,
                            self.__relative)
 
     def mkfile(self, filename):
@@ -555,6 +556,7 @@ class WebappAdd:
                            file_type,
                            self.__destd,
                            filename,
+                           dst_name,
                            self.__relative)
 
 



             reply	other threads:[~2011-08-06  1:51 UTC|newest]

Thread overview: 81+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2011-08-06  1:51 Anthony G. Basile [this message]
  -- strict thread matches above, loose matches on Subject: below --
2017-06-22 23:04 [gentoo-commits] proj/webapp-config:master commit in: WebappConfig/ Devan Franchini
2017-02-16  3:09 Devan Franchini
2017-02-16  3:09 Devan Franchini
2017-02-16  3:09 Devan Franchini
2017-02-16  3:09 Devan Franchini
2016-05-12 12:42 Anthony G. Basile
2015-07-11  1:27 Devan Franchini
2015-07-03  4:50 Devan Franchini
2015-07-02 16:49 Devan Franchini
2015-06-19 22:38 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2015-06-19 19:52 Devan Franchini
2014-01-25  3:17 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-25  3:14 Devan Franchini
2014-01-02  1:47 Devan Franchini
2014-01-01  1:09 Devan Franchini
2013-10-29 19:13 Devan Franchini
2013-10-29  2:40 Devan Franchini
2013-10-29  2:40 Devan Franchini
2013-10-29  2:40 Devan Franchini
2013-10-29  2:40 Devan Franchini
2013-10-29  2:40 Devan Franchini
2013-10-29  2:18 Devan Franchini
2013-10-29  2:18 Devan Franchini
2013-10-29  2:15 Devan Franchini
2013-10-10  0:35 Devan Franchini
2013-09-26  4:03 Devan Franchini
2013-09-26  3:44 Devan Franchini
2013-09-24 18:20 Anthony G. Basile
2013-09-24 18:20 Anthony G. Basile
2013-09-24 18:20 Anthony G. Basile
2013-09-24 18:20 Anthony G. Basile
2013-08-06 12:28 Anthony G. Basile
2013-08-06 11:00 Anthony G. Basile
2013-08-06 11:00 Anthony G. Basile
2013-08-03 13:24 Anthony G. Basile
2013-08-03 13:24 Anthony G. Basile
2013-08-03 13:24 Anthony G. Basile
2013-04-22  0:52 Anthony G. Basile
2013-03-23  4:05 Anthony G. Basile
2013-03-14  2:19 Anthony G. Basile
2013-03-09 13:45 Anthony G. Basile
2013-02-12  3:40 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2012-06-29 13:00 Anthony G. Basile
2011-12-30 17:52 Anthony G. Basile
2011-12-30 17:50 Anthony G. Basile
2011-12-30 17:34 Anthony G. Basile
2011-12-30 17:23 Anthony G. Basile
2011-12-30 17:11 Anthony G. Basile
2011-12-30 16:50 Anthony G. Basile
2011-12-30 16:42 Anthony G. Basile
2011-06-14 15:23 Anthony G. Basile

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=6f368b35014b67c23d0eea35ed6791718f950af3.blueness@gentoo \
    --to=blueness@gentoo.org \
    --cc=gentoo-commits@lists.gentoo.org \
    --cc=gentoo-dev@lists.gentoo.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/WebappConfig/content.py b/WebappConfig/content.py
index 0549622..a469921 100644
--- a/WebappConfig/content.py
+++ b/WebappConfig/content.py
@@ -321,6 +321,7 @@ class Contents:
             ctype,
             destination,
             path,
+            real_path,
             relative = True):
         '''
         Add an entry to the contents file.
@@ -376,7 +377,9 @@ class Contents:
           ctype       - internal webapp-config type
                       - (server-owned | config-owned | virtual)
           destination - install dir (normally $G_INSTALLDIR)
-          entry       - filename inside 'destination'
+          path        - filename inside 'destination'
+          real_path   - for config-protected files realpath =! path
+                        (and this is important for md5)
           relative    - 1 for storing a relative filename, 0 otherwise
 
         >>> OUT.color_off()
@@ -509,7 +512,7 @@ class Contents:
                                       ctype,
                                       '"' + path + '"',
                                       self.file_time(entry),
-                                      a[1](entry),
+                                      a[1](real_path),
                                       a[2](entry)]
 
             if self.__v:
